<?php
/**
 * @version		2.0.1
 * @package		Joomla
 * @subpackage	EShop
 * @author  	Giang Dinh Truong
 * @copyright	Copyright (C) 2012 Ossolution Team
 * @license		GNU/GPL, see LICENSE.php
 */
// no direct access
defined('_JEXEC') or die();

class os_stripe extends EShopOmnipayPayment
{

	protected $omnipayPackage = 'Stripe';

	/**
	 * Constructor
	 *
	 * @param JRegistry $params
	 * @param array     $config
	 */
	public function __construct($params, $config = array('type' => 1))
	{
		// Use sandbox API keys if available
		if (!$params->get('mode', 1))
		{
			if ($params->get('sandbox_stripe_public_key'))
			{
				$params->set('stripe_public_key', $params->get('sandbox_stripe_public_key'));
			}

			if ($params->get('sandbox_stripe_api_key'))
			{
				$params->set('stripe_api_key', $params->get('sandbox_stripe_api_key'));
			}
		}
		
		$config['params_map'] = array(
			'apiKey' => 'stripe_api_key'
		);

		$document  = JFactory::getDocument();
		$publicKey = $params->get('stripe_public_key');

		if ($params->get('use_stripe_card_element', 0))
		{
			$db    = JFactory::getDbo();
			$query = $db->getQuery(true)
				->select($db->quoteName('sef'))
				->from('#__languages')
				->where('lang_code = ' . $db->quote(JFactory::getLanguage()->getTag()))
				->where('published = 1');
			$db->setQuery($query);
			$locale           = substr($db->loadResult(), 0, 2);
			$supportedLocales = ['ar', 'da', 'de', 'en', 'es', 'fi', 'fr', 'he', 'it', 'ja', 'no', 'nl', 'pl', 'sv', 'zh'];

			$document->addScript('https://js.stripe.com/v3/');

			if (in_array($locale, $supportedLocales))
			{
				$document->addScriptDeclaration(
					"   var stripe = Stripe('$publicKey');\n
						var elements = stripe.elements({locale: '$locale'});\n
					"
				);
			}
			else
			{
				$document->addScriptDeclaration(
					"   var stripe = Stripe('$publicKey');\n
						var elements = stripe.elements();\n
					"
				);
			}

			$config['type'] = 0;
		}
		else
		{
			$document->addScript('https://js.stripe.com/v2/');
			$document->addScriptDeclaration(
				"   var stripePublicKey = '$publicKey';\n
					Stripe.setPublishableKey('$publicKey');\n
				"
			);
		}

		parent::__construct($params, $config);
	}

	/**
	 * Add stripeToken to request message
	 *
	 * @param \Omnipay\Common\Message\AbstractRequest $request
	 * @param JTable                                  $row
	 * @param array                                   $data
	 */
	protected function beforeRequestSend($request, $row, $data)
	{
		parent::beforeRequestSend($request, $row, $data);

		$request->setToken($data['stripeToken']);
	}
}